@@ -5,7 +5,6 @@ except ImportError:
 
 import mock
 
-import django
 from django import forms
 from django.core.exceptions import ImproperlyConfigured
 from django.conf import settings
@@ -235,8 +234,9 @@ class TestBetterForm(TestCase):
             c = forms.CharField()
 
         form = TestForm()
-        fields = [field.field for field in form]
-        self.assertItemsEqual(fields, form.fields.values())
+        fields_iter = sorted((field.field for field in form), key=id)
+        fields_values = sorted(form.fields.values(), key=id)
+        self.assertSequenceEqual(fields_iter, fields_values)
 
 
 class TestBetterModelForm(TestCase):
@@ -311,6 +311,10 @@ class TestBetterModelForm(TestCase):
 class TestFormRendering(TestCase):
     def setUp(self):
         class TestForm(BetterForm):
+            # Set the label_suffix to an empty string for consistent results
+            # across Django 1.5 and 1.6.
+            label_suffix = ''
+
             a = forms.CharField()
             b = forms.CharField()
             c = forms.CharField()
@@ -322,9 +326,12 @@ class TestFormRendering(TestCase):
                 )
         self.TestForm = TestForm
 
-    @unittest.skipIf(django.get_version().startswith('1.3'), "Django < 1.4 doesn't have `assertHTMLEqual`")
     def test_non_fieldset_form_rendering(self):
         class TestForm(BetterForm):
+            # Set the label_suffix to an empty string for consistent results
+            # across Django 1.5 and 1.6.
+            label_suffix = ''
+
             a = forms.CharField()
             b = forms.CharField()
             c = forms.CharField()
@@ -333,11 +340,11 @@ class TestFormRendering(TestCase):
         env = {
             'form': form,
             'no_head': True,
-            'fieldset_template_name': 'partials/fieldset_as_div.html',
-            'field_template_name': 'partials/field_as_div.html',
+            'fieldset_template_name': 'betterforms/fieldset_as_div.html',
+            'field_template_name': 'betterforms/field_as_div.html',
         }
         self.assertHTMLEqual(
-            render_to_string('partials/form_as_fieldsets.html', env),
+            render_to_string('betterforms/form_as_fieldsets.html', env),
             """
             <div class="required a formField">
                 <label for="id_a">A</label>
@@ -355,7 +362,7 @@ class TestFormRendering(TestCase):
         )
         form.field_error('a', 'this is an error message')
         self.assertHTMLEqual(
-            render_to_string('partials/form_as_fieldsets.html', env),
+            render_to_string('betterforms/form_as_fieldsets.html', env),
             """
             <div class="required error a formField">
                 <label for="id_a">A</label>
@@ -373,17 +380,16 @@ class TestFormRendering(TestCase):
             """,
         )
 
-    @unittest.skipIf(django.get_version().startswith('1.3'), "Django < 1.4 doesn't have `assertHTMLEqual`")
     def test_include_tag_rendering(self):
         form = self.TestForm()
         env = {
             'form': form,
             'no_head': True,
-            'fieldset_template_name': 'partials/fieldset_as_div.html',
-            'field_template_name': 'partials/field_as_div.html',
+            'fieldset_template_name': 'betterforms/fieldset_as_div.html',
+            'field_template_name': 'betterforms/field_as_div.html',
         }
         self.assertHTMLEqual(
-            render_to_string('partials/form_as_fieldsets.html', env),
+            render_to_string('betterforms/form_as_fieldsets.html', env),
             """
             <fieldset class="formFieldset first">
                 <div class="required a formField">
@@ -405,7 +411,7 @@ class TestFormRendering(TestCase):
         )
         form.field_error('a', 'this is an error message')
         self.assertHTMLEqual(
-            render_to_string('partials/form_as_fieldsets.html', env),
+            render_to_string('betterforms/form_as_fieldsets.html', env),
             """
             <fieldset class="formFieldset first">
                 <div class="required error a formField">
@@ -442,7 +448,6 @@ class TestFormRendering(TestCase):
         form = self.TestForm()
         form.as_ul()
 
-    @unittest.skipIf(django.get_version().startswith('1.3'), "Django < 1.4 doesn't have `assertHTMLEqual`")
     def test_form_as_p(self):
         form = self.TestForm()
         self.assertHTMLEqual(
@@ -491,6 +496,45 @@ class TestFormRendering(TestCase):
             """,
         )
 
+    def test_fieldset_legend(self):
+        class TestForm(BetterForm):
+            a = forms.CharField()
+            b = forms.CharField()
+            c = forms.CharField()
+
+            label_suffix = ''
+
+            class Meta:
+                fieldsets = (
+                    Fieldset('first', ('a', 'b'), legend='First Fieldset'),
+                    Fieldset('second', ('c'), legend='Second Fieldset'),
+                )
+
+        form = TestForm()
+        self.assertHTMLEqual(
+            form.as_p(),
+            """
+            <fieldset class="formFieldset first">
+                <legend>First Fieldset</legend>
+                <p class="required">
+                    <label for="id_a">A</label>
+                    <input id="id_a" name="a" type="text" />
+                </p>
+                <p class="required">
+                    <label for="id_b">B</label>
+                    <input id="id_b" name="b" type="text" />
+                </p>
+            </fieldset>
+            <fieldset class="formFieldset second">
+                <legend>Second Fieldset</legend>
+                <p class="required">
+                    <label for="id_c">C</label>
+                    <input id="id_c" name="c" type="text" />
+                </p>
+            </fieldset>
+            """,
+        )
+
 
 class ChangeListModel(models.Model):
     field_a = models.CharField(max_length=255)
